@@ -4,9 +4,14 @@ from numba import njit
 import pytest
 import os
 from collections import namedtuple
+from itertools import product, combinations
+import asyncio
+import pytz
+import dateparser
 
 from vectorbt import settings
-from vectorbt.utils import checks, config, decorators, math, array, random, enum
+from vectorbt.utils import checks, config, decorators, math, array, random, enum, params, attr, datetime, schedule
+from datetime import datetime as _datetime, timedelta as _timedelta, time as _time, timezone as _timezone
 
 from tests.utils import hash
 
@@ -64,6 +69,12 @@ class TestConfig:
         conf.reset()
         assert conf == {'a': 0, 'b': {'c': [1, 2]}}
 
+    def test_get_func_kwargs(self):
+        def f(a, *args, b=2, **kwargs):
+            pass
+
+        assert config.get_func_kwargs(f) == {'b': 2}
+
     def test_merge_dicts(self):
         assert config.merge_dicts({'a': 1}, {'b': 2}) == {'a': 1, 'b': 2}
         assert config.merge_dicts({'a': 1}, {'a': 2}) == {'a': 2}
@@ -855,6 +866,50 @@ class TestDecorators:
         cached_number = g.cache_me(b=np.zeros(1))
         assert g.cache_me(b=np.zeros(1)) != cached_number
 
+
+# ############# attr.py ############# #
+
+class TestAttrs:
+    def test_deep_getattr(self):
+        class A:
+            def a(self, x, y=None):
+                return x + y
+
+        class B:
+            def a(self):
+                return A()
+
+            def b(self, x):
+                return x
+
+            @property
+            def b_prop(self):
+                return 1
+
+        class C:
+            @property
+            def b(self):
+                return B()
+
+            @property
+            def c(self):
+                return 0
+
+        with pytest.raises(Exception) as e_info:
+            _ = attr.deep_getattr(A(), 'a')
+        with pytest.raises(Exception) as e_info:
+            _ = attr.deep_getattr(A(), ('a',))
+        with pytest.raises(Exception) as e_info:
+            _ = attr.deep_getattr(A(), ('a', 1))
+        with pytest.raises(Exception) as e_info:
+            _ = attr.deep_getattr(A(), ('a', (1,)))
+        assert attr.deep_getattr(A(), ('a', (1,), {'y': 1})) == 2
+        assert attr.deep_getattr(C(), 'c') == 0
+        assert attr.deep_getattr(C(), ['c']) == 0
+        assert attr.deep_getattr(C(), ['b', ('b', (1,))]) == 1
+        assert attr.deep_getattr(C(), ['b', ('a',), ('a', (1,), {'y': 1})]) == 2
+        assert attr.deep_getattr(C(), 'b.b_prop') == 1
+
     def test_traverse_attr_kwargs(self):
         class A:
             @decorators.custom_property(some_key=0)
@@ -874,10 +929,10 @@ class TestDecorators:
             @decorators.custom_property(some_key=1)
             def c(self): pass
 
-        assert hash(str(decorators.traverse_attr_kwargs(C))) == 16728515581653529580
-        assert hash(str(decorators.traverse_attr_kwargs(C, key='some_key'))) == 16728515581653529580
-        assert hash(str(decorators.traverse_attr_kwargs(C, key='some_key', value=1))) == 703070484833749378
-        assert hash(str(decorators.traverse_attr_kwargs(C, key='some_key', value=(0, 1)))) == 16728515581653529580
+        assert hash(str(attr.traverse_attr_kwargs(C))) == 2963162802907041721
+        assert hash(str(attr.traverse_attr_kwargs(C, key='some_key'))) == 2963162802907041721
+        assert hash(str(attr.traverse_attr_kwargs(C, key='some_key', value=1))) == 8774823009175420311
+        assert hash(str(attr.traverse_attr_kwargs(C, key='some_key', value=(0, 1)))) == 2963162802907041721
 
 
 # ############# checks.py ############# #
@@ -902,10 +957,10 @@ class TestChecks:
         assert checks.is_frame(pd.DataFrame([1, 2, 3]))
 
     def test_is_array(self):
-        assert not checks.is_array(0)
-        assert checks.is_array(np.array([0]))
-        assert checks.is_array(pd.Series([1, 2, 3]))
-        assert checks.is_array(pd.DataFrame([1, 2, 3]))
+        assert not checks.is_any_array(0)
+        assert checks.is_any_array(np.array([0]))
+        assert checks.is_any_array(pd.Series([1, 2, 3]))
+        assert checks.is_any_array(pd.DataFrame([1, 2, 3]))
 
     def test_is_numba_func(self):
         def test_func(x):
@@ -973,6 +1028,115 @@ class TestChecks:
         assert checks.is_namedtuple(namedtuple('Hello', ['world'])(*range(1)))
         assert not checks.is_namedtuple((0,))
 
+    def test_method_accepts_argument(self):
+        def test(a, *args, b=2, **kwargs):
+            pass
+
+        assert checks.method_accepts_argument(test, 'a')
+        assert not checks.method_accepts_argument(test, 'args')
+        assert checks.method_accepts_argument(test, '*args')
+        assert checks.method_accepts_argument(test, 'b')
+        assert not checks.method_accepts_argument(test, 'kwargs')
+        assert checks.method_accepts_argument(test, '**kwargs')
+        assert not checks.method_accepts_argument(test, 'c')
+
+    def test_is_deep_equal(self):
+        sr = pd.Series([1, 2, 3], index=pd.Index(['a', 'b', 'c'], name='index'), name='name')
+        sr2 = pd.Series([1., 2., 3.], index=sr.index, name=sr.name)
+        sr3 = pd.Series([np.nan, 2., 3.], index=sr.index, name=sr.name)
+        sr4 = pd.Series([np.nan, 2., 3. + 1e-15], index=sr.index, name=sr.name)
+        assert checks.is_deep_equal(sr, sr.copy())
+        assert checks.is_deep_equal(sr2, sr2.copy())
+        assert checks.is_deep_equal(sr3, sr3.copy())
+        assert checks.is_deep_equal(sr4, sr4.copy())
+        assert not checks.is_deep_equal(sr, sr2)
+        assert checks.is_deep_equal(sr3, sr4)
+        assert not checks.is_deep_equal(sr3, sr4, rtol=0, atol=1e-16)
+        assert not checks.is_deep_equal(sr3, sr4, check_exact=True)
+        assert not checks.is_deep_equal(sr, sr.rename('name2'))
+        assert checks.is_deep_equal(sr.index, sr.copy().index)
+        assert not checks.is_deep_equal(sr.index, sr.copy().index[:-1])
+        assert not checks.is_deep_equal(sr.index, sr.copy().rename('indx2'))
+        assert checks.is_deep_equal(sr.to_frame(), sr.to_frame().copy())
+        assert not checks.is_deep_equal(sr, sr.to_frame().copy())
+        assert not checks.is_deep_equal(sr.to_frame(), sr.copy())
+
+        arr = np.array([1, 2, 3])
+        arr2 = np.array([1., 2., 3.])
+        arr3 = np.array([np.nan, 2., 3.])
+        arr4 = np.array([np.nan, 2., 3 + 1e-15])
+        assert checks.is_deep_equal(arr, arr.copy())
+        assert checks.is_deep_equal(arr2, arr2.copy())
+        assert checks.is_deep_equal(arr3, arr3.copy())
+        assert checks.is_deep_equal(arr4, arr4.copy())
+        assert not checks.is_deep_equal(arr, arr2)
+        assert checks.is_deep_equal(arr3, arr4)
+        assert not checks.is_deep_equal(arr3, arr4, rtol=0, atol=1e-16)
+        assert not checks.is_deep_equal(arr3, arr4, check_exact=True)
+
+        records_arr = np.asarray([
+            (1, 1.),
+            (2, 2.),
+            (3, 3.),
+        ], dtype=np.dtype([
+            ('a', np.int32),
+            ('b', np.float64)
+        ]))
+        records_arr2 = np.asarray([
+            (1., 1.),
+            (2., 2.),
+            (3., 3.),
+        ], dtype=np.dtype([
+            ('a', np.float64),
+            ('b', np.float64)
+        ]))
+        records_arr3 = np.asarray([
+            (np.nan, 1.),
+            (2., 2.),
+            (3., 3.),
+        ], dtype=np.dtype([
+            ('a', np.float64),
+            ('b', np.float64)
+        ]))
+        records_arr4 = np.asarray([
+            (np.nan, 1.),
+            (2., 2.),
+            (3. + 1e-15, 3.),
+        ], dtype=np.dtype([
+            ('a', np.float64),
+            ('b', np.float64)
+        ]))
+        assert checks.is_deep_equal(records_arr, records_arr.copy())
+        assert checks.is_deep_equal(records_arr2, records_arr2.copy())
+        assert checks.is_deep_equal(records_arr3, records_arr3.copy())
+        assert checks.is_deep_equal(records_arr4, records_arr4.copy())
+        assert not checks.is_deep_equal(records_arr, records_arr2)
+        assert checks.is_deep_equal(records_arr3, records_arr4)
+        assert not checks.is_deep_equal(records_arr3, records_arr4, rtol=0, atol=1e-16)
+        assert not checks.is_deep_equal(records_arr3, records_arr4, check_exact=True)
+
+        assert checks.is_deep_equal([sr, arr, records_arr], [sr, arr, records_arr])
+        assert not checks.is_deep_equal([sr, arr, records_arr], [sr, arr, records_arr2])
+        assert not checks.is_deep_equal([sr, arr, records_arr], [sr, records_arr, arr])
+        assert checks.is_deep_equal(
+            {'sr': sr, 'arr': arr, 'records_arr': records_arr},
+            {'sr': sr, 'arr': arr, 'records_arr': records_arr}
+        )
+        assert not checks.is_deep_equal(
+            {'sr': sr, 'arr': arr, 'records_arr': records_arr},
+            {'sr': sr, 'arr': arr, 'records_arr2': records_arr}
+        )
+        assert not checks.is_deep_equal(
+            {'sr': sr, 'arr': arr, 'records_arr': records_arr},
+            {'sr': sr, 'arr': arr, 'records_arr': records_arr2}
+        )
+
+        assert checks.is_deep_equal(0, 0)
+        assert not checks.is_deep_equal(0, False)
+        assert not checks.is_deep_equal(0, 1)
+        assert checks.is_deep_equal(lambda x: x, lambda x: x)
+        assert not checks.is_deep_equal(lambda x: x, lambda x: 2 * x)
+
     def test_assert_in(self):
         checks.assert_in(0, (0, 1))
         with pytest.raises(Exception) as e_info:
@@ -1376,3 +1540,193 @@ class TestEnum:
 
     def test_to_value_map(self):
         assert enum.to_value_map(Enum) == {-1: None, 0: 'Attr1', 1: 'Attr2'}
+
+
+# ############# params.py ############# #
+
+class TestParams:
+    def test_create_param_combs(self):
+        assert params.create_param_combs(
+            (combinations, [0, 1, 2, 3], 2)) == [
+                   [0, 0, 0, 1, 1, 2],
+                   [1, 2, 3, 2, 3, 3]
+               ]
+        assert params.create_param_combs(
+            (product, (combinations, [0, 1, 2, 3], 2), [4, 5])) == [
+                   [0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 2],
+                   [1, 1, 2, 2, 3, 3, 2, 2, 3, 3, 3, 3],
+                   [4, 5, 4, 5, 4, 5, 4, 5, 4, 5, 4, 5]
+               ]
+        assert params.create_param_combs(
+            (product, (combinations, [0, 1, 2], 2), (combinations, [3, 4, 5], 2))) == [
+                   [0, 0, 0, 0, 0, 0, 1, 1, 1],
+                   [1, 1, 1, 2, 2, 2, 2, 2, 2],
+                   [3, 3, 4, 3, 3, 4, 3, 3, 4],
+                   [4, 5, 5, 4, 5, 5, 4, 5, 5]
+               ]
+
+
+# ############# datetime.py ############# #
+
+class TestDatetime:
+    def test_to_timedelta(self):
+        assert datetime.to_timedelta('d') == pd.to_timedelta('1d')
+
+    def test_get_utc_tz(self):
+        assert datetime.get_utc_tz().utcoffset(_datetime.now()) == _timedelta(0)
+
+    def test_get_local_tz(self):
+        assert datetime.get_local_tz().utcoffset(_datetime.now()) == _datetime.now().astimezone(None).utcoffset()
+
+    def test_convert_tzaware_time(self):
+        assert datetime.convert_tzaware_time(
+            _time(12, 0, 0, tzinfo=datetime.get_utc_tz()), _timezone(_timedelta(hours=2))) == \
+               _time(14, 0, 0, tzinfo=_timezone(_timedelta(hours=2)))
+
+    def test_tzaware_to_naive_time(self):
+        assert datetime.tzaware_to_naive_time(
+            _time(12, 0, 0, tzinfo=datetime.get_utc_tz()), _timezone(_timedelta(hours=2))) == _time(14, 0, 0)
+
+    def test_naive_to_tzaware_time(self):
+        assert datetime.naive_to_tzaware_time(
+            _time(12, 0, 0), _timezone(_timedelta(hours=2))) == \
+               datetime.convert_tzaware_time(
+                   _time(12, 0, 0, tzinfo=datetime.get_local_tz()), _timezone(_timedelta(hours=2)))
+
+    def test_convert_naive_time(self):
+        assert datetime.convert_naive_time(
+            _time(12, 0, 0), _timezone(_timedelta(hours=2))) == \
+               datetime.tzaware_to_naive_time(
+                   _time(12, 0, 0, tzinfo=datetime.get_local_tz()), _timezone(_timedelta(hours=2)))
+
+    def test_is_tz_aware(self):
+        assert not datetime.is_tz_aware(pd.Timestamp('2020-01-01'))
+        assert datetime.is_tz_aware(pd.Timestamp('2020-01-01', tz=datetime.get_utc_tz()))
+
+    def test_to_timezone(self):
+        assert datetime.to_timezone('UTC') == pytz.UTC
+        assert datetime.to_timezone('Europe/Berlin') == pytz.timezone('Europe/Berlin')
+        assert datetime.to_timezone('+0500') == _timezone(_timedelta(hours=5))
+        assert datetime.to_timezone(_timezone(_timedelta(hours=1))) == _timezone(_timedelta(hours=1))
+        assert datetime.to_timezone(pytz.timezone('Europe/Berlin')) == pytz.timezone('Europe/Berlin')
+        assert datetime.to_timezone(1) == _timezone(_timedelta(hours=1))
+        assert datetime.to_timezone(0.5) == _timezone(_timedelta(hours=0.5))
+        with pytest.raises(Exception) as e_info:
+            _ = datetime.to_timezone('+05')
+
+    def test_to_tzaware_datetime(self):
+        assert datetime.to_tzaware_datetime(0.5) == \
+               _datetime(1970, 1, 1, 0, 0, 0, 500000, tzinfo=datetime.get_utc_tz())
+        assert datetime.to_tzaware_datetime(0) == \
+               _datetime(1970, 1, 1, 0, 0, 0, 0, tzinfo=datetime.get_utc_tz())
+        assert datetime.to_tzaware_datetime(pd.Timestamp('2020-01-01').value) == \
+               _datetime(2020, 1, 1).replace(tzinfo=datetime.get_utc_tz())
+        assert datetime.to_tzaware_datetime('2020-01-01') == \
+               _datetime(2020, 1, 1).replace(tzinfo=datetime.get_local_tz())
+        assert datetime.to_tzaware_datetime(pd.Timestamp('2020-01-01')) == \
+               _datetime(2020, 1, 1).replace(tzinfo=datetime.get_local_tz())
+        assert datetime.to_tzaware_datetime(pd.Timestamp('2020-01-01', tz=datetime.get_utc_tz())) == \
+               _datetime(2020, 1, 1).replace(tzinfo=datetime.get_utc_tz())
+        assert datetime.to_tzaware_datetime(_datetime(2020, 1, 1)) == \
+               _datetime(2020, 1, 1).replace(tzinfo=datetime.get_local_tz())
+        assert datetime.to_tzaware_datetime(_datetime(2020, 1, 1, tzinfo=datetime.get_utc_tz())) == \
+               _datetime(2020, 1, 1).replace(tzinfo=datetime.get_utc_tz())
+        assert datetime.to_tzaware_datetime(
+            _datetime(2020, 1, 1, 12, 0, 0, tzinfo=datetime.get_utc_tz()), tz=datetime.get_local_tz()) == \
+               _datetime(2020, 1, 1, 12, 0, 0, tzinfo=datetime.get_utc_tz()).astimezone(datetime.get_local_tz())
+        with pytest.raises(Exception) as e_info:
+            _ = datetime.to_tzaware_datetime('2020-01-001')
+
+    def test_datetime_to_ms(self):
+        assert datetime.datetime_to_ms(_datetime(2020, 1, 1)) == \
+               1577836800000 - _datetime(2020, 1, 1).astimezone(None).utcoffset().total_seconds() * 1000
+        assert datetime.datetime_to_ms(_datetime(2020, 1, 1, tzinfo=datetime.get_utc_tz())) == 1577836800000
+
+
+# ############# schedule.py ############# #
+
+
+class TestScheduleManager:
+    def test_every(self):
+        manager = schedule.ScheduleManager()
+        job = manager.every()
+        assert job.interval == 1
+        assert job.unit == 'seconds'
+        assert job.at_time is None
+        assert job.start_day is None
+
+        job = manager.every(10, 'minutes')
+        assert job.interval == 10
+        assert job.unit == 'minutes'
+        assert job.at_time is None
+        assert job.start_day is None
+
+        job = manager.every('hour')
+        assert job.interval == 1
+        assert job.unit == 'hours'
+        assert job.at_time is None
+        assert job.start_day is None
+
+        job = manager.every('10:30')
+        assert job.interval == 1
+        assert job.unit == 'days'
+        assert job.at_time == _time(10, 30)
+        assert job.start_day is None
+
+        job = manager.every('day', '10:30')
+        assert job.interval == 1
+        assert job.unit == 'days'
+        assert job.at_time == _time(10, 30)
+        assert job.start_day is None
+
+        job = manager.every('day', _time(9, 30, tzinfo=datetime.get_utc_tz()))
+        assert job.interval == 1
+        assert job.unit == 'days'
+        assert job.at_time == datetime.tzaware_to_naive_time(
+            _time(9, 30, tzinfo=datetime.get_utc_tz()), datetime.get_local_tz())
+        assert job.start_day is None
+
+        job = manager.every('monday')
+        assert job.interval == 1
+        assert job.unit == 'weeks'
+        assert job.at_time is None
+        assert job.start_day == 'monday'
+
+        job = manager.every('wednesday', '13:15')
+        assert job.interval == 1
+        assert job.unit == 'weeks'
+        assert job.at_time == _time(13, 15)
+        assert job.start_day == 'wednesday'
+
+        job = manager.every('minute', ':17')
+        assert job.interval == 1
+        assert job.unit == 'minutes'
+        assert job.at_time == _time(0, 0, 17)
+        assert job.start_day is None
+
+    def test_start(self):
+        kwargs = dict(call_count=0)
+
+        def job_func(kwargs):
+            kwargs['call_count'] += 1
+            if kwargs['call_count'] == 5:
+                raise KeyboardInterrupt
+
+        manager = schedule.ScheduleManager()
+        manager.every().do(job_func, kwargs)
+        manager.start()
+        assert kwargs['call_count'] == 5
+
+    def test_async_start(self):
+        kwargs = dict(call_count=0)
+
+        def job_func(kwargs):
+            kwargs['call_count'] += 1
+            if kwargs['call_count'] == 5:
+                raise schedule.CancelledError
+
+        manager = schedule.ScheduleManager()
+        manager.every().do(job_func, kwargs)
+        loop = asyncio.get_event_loop()
+        loop.run_until_complete(manager.async_start())
+        assert kwargs['call_count'] == 5
