@@ -1,4 +1,86 @@
-"""Class for wrapping NumPy arrays into Series/DataFrames."""
+"""Class for wrapping NumPy arrays into Series/DataFrames.
+
+vectorbt's functionality is based upon the ability to perform the most essential pandas operations
+using NumPy+Numba stack. One has to convert the Series/DataFrame into the NumPy format, perform
+the computation, and put the array back into the pandas format. The last step is done using
+`ArrayWrapper`.
+
+It stores metadata of the original pandas object and offers methods `wrap` and `wrap_reduced`
+for wrapping NumPy arrays to match the stored metadata as closest as possible.
+
+```python-repl
+>>> import numpy as np
+>>> import pandas as pd
+>>> import vectorbt as vbt
+>>> from vectorbt.base.array_wrapper import ArrayWrapper
+
+>>> aw = ArrayWrapper(index=['x', 'y', 'z'], columns=['a', 'b', 'c'], ndim=2)
+>>> aw._config
+{
+    'columns': Index(['a', 'b', 'c'], dtype='object'),
+    'group_select': None,
+    'ndim': 2,
+    'freq': None,
+    'column_only_select': None,
+    'grouped_ndim': None,
+    'index': ['x', 'y', 'z'],
+    'allow_modify': True,
+    'allow_enable': True,
+    'group_by': None,
+    'allow_disable': True
+}
+
+>>> np.random.seed(42)
+>>> a = np.random.uniform(size=(3, 3))
+>>> aw.wrap(a)
+          a         b         c
+x  0.374540  0.950714  0.731994
+y  0.598658  0.156019  0.155995
+z  0.058084  0.866176  0.601115
+
+>>> aw.wrap_reduced(np.sum(a, axis=0))
+a    1.031282
+b    1.972909
+c    1.489103
+dtype: float64
+```
+
+It can also be indexed as a regular pandas object and integrates `vectorbt.base.column_grouper.ColumnGrouper`:
+
+```python-repl
+>>> aw.loc['x':'y', 'a']._config
+{
+    'columns': Index(['a'], dtype='object'),
+    'group_select': None,
+    'ndim': 1,
+    'freq': None,
+    'column_only_select': None,
+    'grouped_ndim': None,
+    'index': Index(['x', 'y'], dtype='object'),
+    'allow_modify': True,
+    'allow_enable': True,
+    'group_by': None,
+    'allow_disable': True
+}
+
+>>> aw.regroup(np.array([0, 0, 1]))._config
+{
+    'columns': Index(['a', 'b', 'c'], dtype='object'),
+    'group_select': None,
+    'ndim': 2,
+    'freq': None,
+    'column_only_select': None,
+    'grouped_ndim': None,
+    'index': ['x', 'y', 'z'],
+    'allow_modify': True,
+    'allow_enable': True,
+    'group_by': array([0, 0, 1]),
+    'allow_disable': True
+}
+```
+
+Class `Wrapping` is a convenience class meant to be subclassed by classes that do not want to subclass
+`ArrayWrapper` but rather use it as an attribute (which is a better SE design pattern anyway!)."""
 
 import numpy as np
 import pandas as pd
@@ -6,7 +88,7 @@ import warnings
 
 from vectorbt.utils import checks
 from vectorbt.utils.config import Configured, merge_dicts
-from vectorbt.utils.datetime import freq_delta, DatetimeTypes, to_time_units
+from vectorbt.utils.datetime import to_timedelta, DatetimeTypes
 from vectorbt.utils.array import get_ranges_arr
 from vectorbt.utils.decorators import cached_method
 from vectorbt.base import index_fns, reshape_fns
@@ -240,6 +322,14 @@ class ArrayWrapper(Configured, PandasIndexer):
         ndim = obj.ndim
         return cls(index, columns, ndim, *args, **kwargs)
 
+    @classmethod
+    def from_shape(cls, shape, *args, **kwargs):
+        """Derive metadata from shape."""
+        index = pd.RangeIndex(start=0, step=1, stop=shape[0])
+        columns = pd.RangeIndex(start=0, step=1, stop=shape[1] if len(shape) > 1 else 1)
+        ndim = len(shape)
+        return cls(index, columns, ndim, *args, **kwargs)
+
     @property
     def index(self):
         """Index."""
@@ -307,16 +397,16 @@ class ArrayWrapper(Configured, PandasIndexer):
         if freq is None:
             freq = settings.array_wrapper['freq']
         if freq is not None:
-            return freq_delta(freq)
+            return to_timedelta(freq)
         if isinstance(self.index, DatetimeTypes):
             if self.index.freq is not None:
                 try:
-                    return freq_delta(self.index.freq)
+                    return to_timedelta(self.index.freq)
                 except ValueError as e:
                     warnings.warn(repr(e), stacklevel=2)
             if self.index.inferred_freq is not None:
                 try:
-                    return freq_delta(self.index.inferred_freq)
+                    return to_timedelta(self.index.inferred_freq)
                 except ValueError as e:
                     warnings.warn(repr(e), stacklevel=2)
         return freq
@@ -325,7 +415,7 @@ class ArrayWrapper(Configured, PandasIndexer):
         """Convert array to time units."""
         if self.freq is None:
             raise ValueError("Couldn't parse the frequency of index. You must set `freq`.")
-        return to_time_units(a, self.freq)
+        return a * to_timedelta(self.freq)
 
     @property
     def column_only_select(self):
@@ -408,10 +498,11 @@ class ArrayWrapper(Configured, PandasIndexer):
             return pd.DataFrame(a, index=index, columns=columns, dtype=dtype)
         raise ValueError(f"{a.ndim}-d input is not supported")
 
-    def wrap_reduced(self, a, index=None, columns=None, time_units=False, dtype=None, group_by=None):
+    def wrap_reduced(self, a, name_or_index=None, columns=None, dtype=None, group_by=None, time_units=False):
         """Wrap result of reduction.
 
-        `index` can be set when reducing to an array of values (vs. one value) per column.
+        `name_or_index` can be the name of the resulting series if reducing to a scalar per column,
+        or the index of the resulting series/dataframe if reducing to an array per column.
         `columns` can be set to override object's default columns.
 
         If `time_units` is set, calls `to_time_units`."""
@@ -428,6 +519,7 @@ class ArrayWrapper(Configured, PandasIndexer):
                 warnings.warn(repr(e), stacklevel=2)
         if time_units:
             a = _self.to_time_units(a)
+            dtype = None
         if a.ndim == 0:
             # Scalar per Series/DataFrame
             if time_units:
@@ -441,23 +533,21 @@ class ArrayWrapper(Configured, PandasIndexer):
                         return pd.to_timedelta(a[0])
                     return a[0]
                 # Array per Series
-                name = columns[0]
-                if name == 0:  # was a Series before
-                    name = None
-                return pd.Series(a, index=index, name=name, dtype=dtype)
+                sr_name = columns[0]
+                if sr_name == 0:  # was a Series before
+                    sr_name = None
+                return pd.Series(a, index=name_or_index, name=sr_name, dtype=dtype)
             # Scalar per column in a DataFrame
-            if index is None:
-                index = columns
-            return pd.Series(a, index=index, dtype=dtype)
+            return pd.Series(a, index=columns, name=name_or_index, dtype=dtype)
         if a.ndim == 2:
             if a.shape[1] == 1 and _self.ndim == 1:
                 # Array per Series
-                name = columns[0]
-                if name == 0:  # was a Series before
-                    name = None
-                return pd.Series(a[:, 0], index=index, name=name, dtype=dtype)
+                sr_name = columns[0]
+                if sr_name == 0:  # was a Series before
+                    sr_name = None
+                return pd.Series(a[:, 0], index=name_or_index, name=sr_name, dtype=dtype)
             # Array per column in a DataFrame
-            return pd.DataFrame(a, index=index, columns=columns, dtype=dtype)
+            return pd.DataFrame(a, index=name_or_index, columns=columns, dtype=dtype)
         raise ValueError(f"{a.ndim}-d input is not supported")
 
     def dummy(self, group_by=None, **kwargs):
