@@ -1,4 +1,7 @@
-"""Functions for reshaping arrays."""
+"""Functions for reshaping arrays.
+
+Reshape functions transform a pandas object/NumPy array in some way, such as tiling, broadcasting,
+and unstacking."""
 
 import numpy as np
 import pandas as pd
@@ -10,7 +13,7 @@ from vectorbt.base import index_fns, array_wrapper
 
 def soft_to_ndim(arg, ndim):
     """Try to softly bring `arg` to the specified number of dimensions `ndim` (max 2)."""
-    if not checks.is_array(arg):
+    if not checks.is_any_array(arg):
         arg = np.asarray(arg)
     if ndim == 1:
         if arg.ndim == 2:
@@ -31,7 +34,7 @@ def to_1d(arg, raw=False):
 
     If `raw` is True, returns NumPy array.
     If 2-dim, will collapse along axis 1 (i.e., DataFrame with one column to Series)."""
-    if raw or not checks.is_array(arg):
+    if raw or not checks.is_any_array(arg):
         arg = np.asarray(arg)
     if arg.ndim == 2:
         if arg.shape[1] == 1:
@@ -50,7 +53,7 @@ def to_2d(arg, raw=False, expand_axis=1):
 
     If `raw` is True, returns NumPy array.
     If 1-dim, will expand along axis 1 (i.e., Series to DataFrame with one column)."""
-    if raw or not checks.is_array(arg):
+    if raw or not checks.is_any_array(arg):
         arg = np.asarray(arg)
     if arg.ndim == 2:
         return arg
@@ -68,7 +71,7 @@ def to_2d(arg, raw=False, expand_axis=1):
 
 def repeat(arg, n, axis=1):
     """Repeat each element in `arg` `n` times along the specified axis."""
-    if not checks.is_array(arg):
+    if not checks.is_any_array(arg):
         arg = np.asarray(arg)
     if axis == 0:
         if checks.is_pandas(arg):
@@ -87,7 +90,7 @@ def repeat(arg, n, axis=1):
 
 def tile(arg, n, axis=1):
     """Repeat the whole `arg` `n` times along the specified axis."""
-    if not checks.is_array(arg):
+    if not checks.is_any_array(arg):
         arg = np.asarray(arg)
     if axis == 0:
         if arg.ndim == 2:
@@ -208,7 +211,7 @@ def broadcast_index(args, to_shape, index_from=None, axis=0, ignore_sr_names=Non
                                         new_index = index_fns.repeat_index(new_index, len(index))
                                     elif len(index) < len(new_index):
                                         index = index_fns.repeat_index(index, len(new_index))
-                                new_index = index_fns.stack_indexes(new_index, index, **kwargs)
+                                new_index = index_fns.stack_indexes([new_index, index], **kwargs)
             else:
                 raise ValueError(f"Invalid value {index_from} for {'columns' if axis == 1 else 'index'}_from")
         else:
@@ -222,7 +225,7 @@ def broadcast_index(args, to_shape, index_from=None, axis=0, ignore_sr_names=Non
                 if maxlen > 1 and len(new_index) > 1:
                     raise ValueError("Indexes could not be broadcast together")
                 new_index = index_fns.repeat_index(new_index, maxlen)
-        elif index_from is not None:
+        else:
             # new_index=None can mean two things: 1) take original metadata or 2) reset index/columns
             # In case when index_from is not None, we choose 2)
             new_index = pd.RangeIndex(start=0, stop=maxlen, step=1)
@@ -421,7 +424,7 @@ def broadcast(*args, to_shape=None, to_pd=None, to_frame=None, align_index=None,
     # Convert to np.ndarray object if not numpy or pandas
     # Also check whether we broadcast to pandas and whether work on 2-dim data
     for i in range(len(args)):
-        if not checks.is_array(args[i]):
+        if not checks.is_any_array(args[i]):
             args[i] = np.asarray(args[i])
         if args[i].ndim > 1:
             is_2d = True
@@ -456,7 +459,7 @@ def broadcast(*args, to_shape=None, to_pd=None, to_frame=None, align_index=None,
         if len(index_to_align) > 1:
             indexes = [args[i].index for i in index_to_align]
             if len(set(map(len, indexes))) > 1:
-                index_indices = index_fns.align_indexes(*indexes)
+                index_indices = index_fns.align_indexes(indexes)
                 for i in range(len(args)):
                     if i in index_to_align:
                         args[i] = args[i].iloc[index_indices[index_to_align.index(i)]]
@@ -468,7 +471,7 @@ def broadcast(*args, to_shape=None, to_pd=None, to_frame=None, align_index=None,
         if len(cols_to_align) > 1:
             indexes = [args[i].columns for i in cols_to_align]
             if len(set(map(len, indexes))) > 1:
-                col_indices = index_fns.align_indexes(*indexes)
+                col_indices = index_fns.align_indexes(indexes)
                 for i in range(len(args)):
                     if i in cols_to_align:
                         args[i] = args[i].iloc[:, col_indices[cols_to_align.index(i)]]
@@ -563,9 +566,9 @@ def broadcast_to(arg1, arg2, to_pd=None, index_from=None, columns_from=None, **k
     array([4, 5, 6])
     ```
     """
-    if not checks.is_array(arg1):
+    if not checks.is_any_array(arg1):
         arg1 = np.asarray(arg1)
-    if not checks.is_array(arg2):
+    if not checks.is_any_array(arg2):
         arg2 = np.asarray(arg2)
     if to_pd is None:
         to_pd = checks.is_pandas(arg2)
@@ -622,7 +625,7 @@ def broadcast_to_axis_of(arg1, arg2, axis, require_kwargs=None):
     For other keyword arguments, see `broadcast`."""
     if require_kwargs is None:
         require_kwargs = {}
-    if not checks.is_array(arg2):
+    if not checks.is_any_array(arg2):
         arg2 = np.asarray(arg2)
     if arg2.ndim < axis + 1:
         return np.broadcast_to(arg1, (1,))[0]  # to a single number
@@ -665,6 +668,8 @@ def unstack_to_array(arg, levels=None):
     """
     checks.assert_type(arg, pd.Series)
     checks.assert_type(arg.index, pd.MultiIndex)
+    if arg.index.duplicated().any():
+        raise ValueError("Index contains duplicate entries, cannot reshape")
 
     unique_idx_list = []
     vals_idx_list = []
