@@ -1,4 +1,20 @@
-"""Base class for working with drawdown records."""
+"""Base class for working with drawdown records.
+
+Class `Drawdowns` accepts drawdown records and the corresponding time series
+to analyze the periods of drawdown. Using `Drawdowns.from_ts`, you can generate
+drawdown records for any time series and analyze them right away.
+
+Moreover, all time series accessors have a method `drawdowns`:
+
+```python-repl
+>>> import pandas as pd
+>>> import vectorbt as vbt
+
+>>> # vectorbt.generic.accessors.GenericAccessor.drawdowns.current_drawdown
+>>> pd.Series([5, 4, 3, 4]).vbt.drawdowns.current_drawdown()
+-0.2
+```
+"""
 
 import numpy as np
 import pandas as pd
@@ -9,7 +25,7 @@ from vectorbt.utils.config import merge_dicts
 from vectorbt.utils.colors import adjust_lightness
 from vectorbt.utils.datetime import DatetimeTypes
 from vectorbt.utils.enum import to_value_map
-from vectorbt.utils.widgets import CustomFigureWidget
+from vectorbt.utils.widgets import FigureWidget
 from vectorbt.base.reshape_fns import to_1d
 from vectorbt.base.array_wrapper import ArrayWrapper
 from vectorbt.generic import nb
@@ -28,32 +44,31 @@ class Drawdowns(Records):
     >>> import vectorbt as vbt
     >>> import numpy as np
     >>> import pandas as pd
-    >>> import yfinance as yf
     >>> from datetime import datetime
 
     >>> start = datetime(2019, 1, 1)
     >>> end = datetime(2020, 1, 1)
-    >>> price = yf.Ticker("BTC-USD").history(start=start, end=end)['Close']
+    >>> price = vbt.YFData.download('BTC-USD', start=start, end=end).get('Close')
     >>> drawdowns = vbt.Drawdowns.from_ts(price, freq='1 days')
 
     >>> drawdowns.records.head()
        id  col  start_idx  valley_idx  end_idx  status
-    0   0    0          2           3        6       1
-    1   1    0          6          38       54       1
-    2   2    0         54          63       91       1
-    3   3    0         93          94       95       1
-    4   4    0         98          99      100       1
+    0   0    0          1           2        5       1
+    1   1    0          5          37       53       1
+    2   2    0         53          62       90       1
+    3   3    0         92          93       94       1
+    4   4    0         97          98       99       1
 
     >>> drawdowns.drawdown
     <vectorbt.records.base.MappedArray at 0x7fafa6a11160>
 
     >>> drawdowns.drawdown.min()
-    -0.48982769972565016
+    -0.48982813000684766
 
-    >>> drawdowns.drawdown.hist(trace_kwargs=dict(nbinsx=50))
+    >>> drawdowns.drawdown.histplot(trace_kwargs=dict(nbinsx=50))
     ```
 
-    ![](/vectorbt/docs/img/drawdowns_drawdown_hist.png)
+    ![](/vectorbt/docs/img/drawdowns_drawdown_histplot.png)
     """
 
     def __init__(self, wrapper, records_arr, ts, idx_field='end_idx', **kwargs):
@@ -70,10 +85,10 @@ class Drawdowns(Records):
         if not all(field in records_arr.dtype.names for field in drawdown_dt.names):
             raise TypeError("Records array must match drawdown_dt")
 
-    def _indexing_func(self, pd_indexing_func):
+    def _indexing_func(self, pd_indexing_func, **kwargs):
         """Perform indexing on `Drawdowns`."""
         new_wrapper, new_records_arr, _, col_idxs = \
-            Records._indexing_func_meta(self, pd_indexing_func)
+            Records._indexing_func_meta(self, pd_indexing_func, **kwargs)
         new_ts = new_wrapper.wrap(self.ts.values[:, col_idxs], group_by=False)
         return self.copy(
             wrapper=new_wrapper,
@@ -131,11 +146,13 @@ class Drawdowns(Records):
     @cached_method
     def avg_drawdown(self, default_val=0., **kwargs):
         """Average drawdown (ADD)."""
+        kwargs = merge_dicts(dict(wrap_kwargs=dict(name_or_index='avg_drawdown')), kwargs)
         return self.drawdown.mean(default_val=default_val, **kwargs)
 
     @cached_method
     def max_drawdown(self, default_val=0., **kwargs):
         """Maximum drawdown (MDD)."""
+        kwargs = merge_dicts(dict(wrap_kwargs=dict(name_or_index='max_drawdown')), kwargs)
         return self.drawdown.min(default_val=default_val, **kwargs)
 
     @cached_property
@@ -144,21 +161,24 @@ class Drawdowns(Records):
         return self.map(nb.dd_duration_map_nb)
 
     @cached_method
-    def avg_duration(self, time_units=True, **kwargs):
+    def avg_duration(self, **kwargs):
         """Average drawdown duration (in time units)."""
-        return self.duration.mean(time_units=time_units, **kwargs)
+        kwargs = merge_dicts(dict(wrap_kwargs=dict(time_units=True, name_or_index='avg_duration')), kwargs)
+        return self.duration.mean(**kwargs)
 
     @cached_method
-    def max_duration(self, time_units=True, **kwargs):
+    def max_duration(self, **kwargs):
         """Maximum drawdown duration (in time units)."""
-        return self.duration.max(time_units=time_units, **kwargs)
+        kwargs = merge_dicts(dict(wrap_kwargs=dict(time_units=True, name_or_index='max_duration')), kwargs)
+        return self.duration.max(**kwargs)
 
     @cached_method
-    def coverage(self, group_by=None, **kwargs):
+    def coverage(self, group_by=None, wrap_kwargs=None):
         """Coverage, that is, total duration divided by the whole period."""
         total_duration = to_1d(self.duration.sum(group_by=group_by), raw=True)
         total_steps = self.wrapper.grouper.get_group_lens(group_by=group_by) * self.wrapper.shape[0]
-        return self.wrapper.wrap_reduced(total_duration / total_steps, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='coverage'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(total_duration / total_steps, group_by=group_by, **wrap_kwargs)
 
     @cached_property
     def ptv_duration(self):
@@ -179,11 +199,12 @@ class Drawdowns(Records):
         return self.filter_by_mask(filter_mask)
 
     @cached_method
-    def active_rate(self, group_by=None, **kwargs):
+    def active_rate(self, group_by=None, wrap_kwargs=None):
         """Rate of recovered drawdowns."""
         active_count = to_1d(self.active.count(group_by=group_by), raw=True)
         total_count = to_1d(self.count(group_by=group_by), raw=True)
-        return self.wrapper.wrap_reduced(active_count / total_count, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='active_rate'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(active_count / total_count, group_by=group_by, **wrap_kwargs)
 
     @cached_property
     def recovered(self):
@@ -192,16 +213,17 @@ class Drawdowns(Records):
         return self.filter_by_mask(filter_mask)
 
     @cached_method
-    def recovered_rate(self, group_by=None, **kwargs):
+    def recovered_rate(self, group_by=None, wrap_kwargs=None):
         """Rate of recovered drawdowns."""
         recovered_count = to_1d(self.recovered.count(group_by=group_by), raw=True)
         total_count = to_1d(self.count(group_by=group_by), raw=True)
-        return self.wrapper.wrap_reduced(recovered_count / total_count, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='recovered_rate'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(recovered_count / total_count, group_by=group_by, **wrap_kwargs)
 
     # ############# DrawdownStatus.Active ############# #
 
     @cached_method
-    def current_drawdown(self, group_by=None, **kwargs):
+    def current_drawdown(self, group_by=None, wrap_kwargs=None):
         """Current drawdown from peak.
 
         Does not support grouping."""
@@ -210,16 +232,18 @@ class Drawdowns(Records):
         curr_end_val = self.active.end_value.nst(-1, group_by=group_by)
         curr_start_val = self.active.start_value.nst(-1, group_by=group_by)
         curr_drawdown = (curr_end_val - curr_start_val) / curr_start_val
-        return self.wrapper.wrap_reduced(curr_drawdown, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='current_drawdown'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(curr_drawdown, group_by=group_by, **wrap_kwargs)
 
     @cached_method
-    def current_duration(self, time_units=True, group_by=None, **kwargs):
+    def current_duration(self, group_by=None, **kwargs):
         """Current duration from peak.
 
         Does not support grouping."""
         if self.wrapper.grouper.is_grouped(group_by=group_by):
             raise ValueError("Grouping is not supported by this method")
-        return self.active.duration.nst(-1, time_units=time_units, group_by=group_by, **kwargs)
+        kwargs = merge_dicts(dict(wrap_kwargs=dict(time_units=True, name_or_index='current_duration')), kwargs)
+        return self.active.duration.nst(-1, group_by=group_by, **kwargs)
 
     @cached_method
     def current_return(self, group_by=None, **kwargs):
@@ -229,6 +253,7 @@ class Drawdowns(Records):
         if self.wrapper.grouper.is_grouped(group_by=group_by):
             raise ValueError("Grouping is not supported by this method")
         recovery_return = self.active.map(nb.dd_recovery_return_map_nb, self.ts.vbt.to_2d_array())
+        kwargs = merge_dicts(dict(wrap_kwargs=dict(name_or_index='current_return')), kwargs)
         return recovery_return.nst(-1, group_by=group_by, **kwargs)
 
     # ############# DrawdownStatus.Recovered ############# #
@@ -265,7 +290,7 @@ class Drawdowns(Records):
              ptv_shape_kwargs=None,
              vtr_shape_kwargs=None,
              active_shape_kwargs=None,
-             row=None, col=None,
+             add_trace_kwargs=None,
              xref='x', yref='y',
              fig=None,
              **layout_kwargs):  # pragma: no cover
@@ -284,8 +309,7 @@ class Drawdowns(Records):
             ptv_shape_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Figure.add_shape` for PtV zones.
             vtr_shape_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Figure.add_shape` for VtR zones.
             active_shape_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Figure.add_shape` for active VtR zones.
-            row (int): Row position.
-            col (int): Column position.
+            add_trace_kwargs (dict): Keyword arguments passed to `add_trace`.
             xref (str): X coordinate axis.
             yref (str): Y coordinate axis.
             fig (plotly.graph_objects.Figure): Figure to add traces to.
@@ -329,9 +353,11 @@ class Drawdowns(Records):
             vtr_shape_kwargs = {}
         if active_shape_kwargs is None:
             active_shape_kwargs = {}
+        if add_trace_kwargs is None:
+            add_trace_kwargs = {}
 
         if fig is None:
-            fig = CustomFigureWidget()
+            fig = FigureWidget()
         fig.update_layout(**layout_kwargs)
         y_domain = [0, 1]
         yaxis = 'yaxis' + yref[1:]
@@ -341,7 +367,7 @@ class Drawdowns(Records):
                     y_domain = fig.layout[yaxis]['domain']
 
         if plot_ts:
-            fig = self_col.ts.vbt.plot(trace_kwargs=ts_trace_kwargs, row=row, col=col, fig=fig)
+            fig = self_col.ts.vbt.plot(trace_kwargs=ts_trace_kwargs, add_trace_kwargs=add_trace_kwargs, fig=fig)
 
         if len(self_col.values) > 0:
             # Extract information
@@ -388,7 +414,7 @@ class Drawdowns(Records):
                                   "<br>Price: %{y}"
                 )
                 peak_scatter.update(**peak_trace_kwargs)
-                fig.add_trace(peak_scatter, row=row, col=col)
+                fig.add_trace(peak_scatter, **add_trace_kwargs)
 
             recovery_mask = status == DrawdownStatus.Recovered
             if np.any(recovery_mask):
@@ -418,7 +444,7 @@ class Drawdowns(Records):
                                   "<br>Duration: %{customdata[2]}"
                 )
                 valley_scatter.update(**valley_trace_kwargs)
-                fig.add_trace(valley_scatter, row=row, col=col)
+                fig.add_trace(valley_scatter, **add_trace_kwargs)
 
                 if plot_zones:
                     # Plot drawdown zones
@@ -463,7 +489,7 @@ class Drawdowns(Records):
                                   "<br>Duration: %{customdata[2]}"
                 )
                 recovery_scatter.update(**recovery_trace_kwargs)
-                fig.add_trace(recovery_scatter, row=row, col=col)
+                fig.add_trace(recovery_scatter, **add_trace_kwargs)
 
                 if plot_zones:
                     # Plot recovery zones
@@ -510,7 +536,7 @@ class Drawdowns(Records):
                                   "<br>Duration: %{customdata[2]}"
                 )
                 active_scatter.update(**active_trace_kwargs)
-                fig.add_trace(active_scatter, row=row, col=col)
+                fig.add_trace(active_scatter, **add_trace_kwargs)
 
                 if plot_zones:
                     # Plot active drawdown zones
