@@ -1,36 +1,56 @@
 """Indicators built with `vectorbt.indicators.factory.IndicatorFactory`.
 
+You can access all the indicators either by `vbt.*` or `vbt.indicators.*`.
+
+```python-repl
+>>> import pandas as pd
+>>> import vectorbt as vbt
+
+>>> # vectorbt.indicators.basic.MA
+>>> vbt.MA.run(pd.Series([1, 2, 3]), [2, 3]).ma
+ma_window     2     3
+ma_ewm    False False
+0           NaN   NaN
+1           1.5   NaN
+2           2.5   2.0
+```
+
+The advantage of these indicators over TA-Lib's is that they work primarily on 2-dimensional arrays
+and utilize caching, which makes them faster for matrices with huge number of columns. They also
+have plotting methods.
+
+Run for the examples below:
+
 ```python-repl
 >>> import vectorbt as vbt
 >>> from datetime import datetime
->>> import yfinance as yf
 
->>> ticker = yf.Ticker("BTC-USD")
->>> price = ticker.history(start=datetime(2019, 3, 1), end=datetime(2019, 9, 1))
->>> price = price[['Open', 'High', 'Low', 'Close', 'Volume']]
->>> price
-                Open      High       Low     Close       Volume
+>>> start = datetime(2019, 3, 1)
+>>> end = datetime(2019, 9, 1)
+>>> cols = ['Open', 'High', 'Low', 'Close', 'Volume']
+>>> ohlcv = vbt.YFData.download("BTC-USD", start=start, end=end).get(cols)
+>>> ohlcv
+                    Open          High          Low        Close       Volume
 Date
-2019-02-28   3848.26   3906.06   3845.82   3854.79   8399767798
-2019-03-01   3853.76   3907.80   3851.69   3859.58   7661247975
-2019-03-02   3855.32   3874.61   3832.13   3864.42   7578786075
-...              ...       ...       ...       ...          ...
-2019-08-29   9756.79   9756.79   9421.63   9510.20  17045878500
-2019-08-30   9514.84   9656.12   9428.30   9598.17  13595263986
-2019-08-31   9597.54   9673.22   9531.80   9630.66  11454806419
+2019-03-01   3853.757080   3907.795410  3851.692383  3859.583740   7661247975
+2019-03-02   3855.318115   3874.607422  3832.127930  3864.415039   7578786076
+2019-03-03   3862.266113   3875.483643  3836.905762  3847.175781   7253558152
+...                  ...           ...          ...          ...          ...
+2019-08-30   9514.844727   9656.124023  9428.302734  9598.173828  13595263986
+2019-08-31   9597.539062   9673.220703  9531.799805  9630.664062  11454806419
+2019-09-01   9630.592773   9796.755859  9582.944336  9757.970703  11445355859
 
 [185 rows x 5 columns]
 
->>> price.vbt.ohlcv.plot()
+>>> ohlcv.vbt.ohlcv.plot()
 ```
-![](/vectorbt/docs/img/Indicators_price.png)"""
+![](/vectorbt/docs/img/basic_price.png)"""
 
 import numpy as np
 import plotly.graph_objects as go
 
 from vectorbt.utils.config import merge_dicts
-from vectorbt.utils.docs import fix_class_for_docs
-from vectorbt.utils.widgets import CustomFigureWidget
+from vectorbt.utils.widgets import FigureWidget
 from vectorbt.generic import nb as generic_nb
 from vectorbt.indicators.factory import IndicatorFactory
 from vectorbt.indicators import nb
@@ -48,26 +68,26 @@ MA = IndicatorFactory(
 ).from_apply_func(
     nb.ma_apply_nb,
     cache_func=nb.ma_cache_nb,
-    ewm=False
+    kwargs_to_args=['adjust'],
+    ewm=False,
+    adjust=False
 )
 
 
-class MA(MA):
+class _MA(MA):
     """Moving Average (MA).
 
     A moving average is a widely used indicator in technical analysis that helps smooth out
     price action by filtering out the “noise” from random short-term price fluctuations. 
 
-    See [Moving Average (MA)](https://www.investopedia.com/terms/m/movingaverage.asp).
-
-    Use `MA.run` or `MA.run_combs` to run the indicator."""
+    See [Moving Average (MA)](https://www.investopedia.com/terms/m/movingaverage.asp)."""
 
     def plot(self,
              column=None,
              plot_close=True,
              close_trace_kwargs=None,
              ma_trace_kwargs=None,
-             row=None, col=None,
+             add_trace_kwargs=None,
              fig=None,
              **layout_kwargs):  # pragma: no cover
         """Plot `MA.ma` against `MA.close`.
@@ -77,15 +97,14 @@ class MA(MA):
             plot_close (bool): Whether to plot `MA.close`.
             close_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `MA.close`.
             ma_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `MA.ma`.
-            row (int): Row position.
-            col (int): Column position.
+            add_trace_kwargs (dict): Keyword arguments passed to `add_trace`.
             fig (plotly.graph_objects.Figure): Figure to add traces to.
             **layout_kwargs: Keyword arguments for layout.
 
         ## Example
 
         ```python-repl
-        >>> vbt.MA.run(price['Close'], 10).plot()
+        >>> vbt.MA.run(ohlcv['Close'], 10).plot()
         ```
 
         ![](/vectorbt/docs/img/MA.png)
@@ -95,7 +114,7 @@ class MA(MA):
         self_col = self.select_series(column=column)
 
         if fig is None:
-            fig = CustomFigureWidget()
+            fig = FigureWidget()
         fig.update_layout(**layout_kwargs)
 
         if close_trace_kwargs is None:
@@ -113,15 +132,16 @@ class MA(MA):
         if plot_close:
             fig = self_col.close.vbt.plot(
                 trace_kwargs=close_trace_kwargs,
-                row=row, col=col, fig=fig)
+                add_trace_kwargs=add_trace_kwargs, fig=fig)
         fig = self_col.ma.vbt.plot(
             trace_kwargs=ma_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
 
         return fig
 
 
-fix_class_for_docs(MA)
+setattr(MA, '__doc__', _MA.__doc__)
+setattr(MA, 'plot', _MA.plot)
 
 # ############# MSTD ############# #
 
@@ -136,22 +156,23 @@ MSTD = IndicatorFactory(
 ).from_apply_func(
     nb.mstd_apply_nb,
     cache_func=nb.mstd_cache_nb,
-    ewm=False
+    kwargs_to_args=['adjust', 'ddof'],
+    ewm=False,
+    adjust=False,
+    ddof=0
 )
 
 
-class MSTD(MSTD):
+class _MSTD(MSTD):
     """Moving Standard Deviation (MSTD).
 
     Standard deviation is an indicator that measures the size of an assets recent price moves
-    in order to predict how volatile the price may be in the future.
-
-    Use `MSTD.run` or `MSTD.run_combs` to run the indicator."""
+    in order to predict how volatile the price may be in the future."""
 
     def plot(self,
              column=None,
              mstd_trace_kwargs=None,
-             row=None, col=None,
+             add_trace_kwargs=None,
              fig=None,
              **layout_kwargs):  # pragma: no cover
         """Plot `MSTD.mstd`.
@@ -159,15 +180,14 @@ class MSTD(MSTD):
         Args:
             column (str): Name of the column to plot.
             mstd_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `MSTD.mstd`.
-            row (int): Row position.
-            col (int): Column position.
+            add_trace_kwargs (dict): Keyword arguments passed to `add_trace`.
             fig (plotly.graph_objects.Figure): Figure to add traces to.
             **layout_kwargs: Keyword arguments for layout.
 
         ## Example
 
         ```python-repl
-        >>> vbt.MSTD.run(price['Close'], 10).plot()
+        >>> vbt.MSTD.run(ohlcv['Close'], 10).plot()
         ```
 
         ![](/vectorbt/docs/img/MSTD.png)
@@ -175,7 +195,7 @@ class MSTD(MSTD):
         self_col = self.select_series(column=column)
 
         if fig is None:
-            fig = CustomFigureWidget()
+            fig = FigureWidget()
         fig.update_layout(**layout_kwargs)
 
         if mstd_trace_kwargs is None:
@@ -186,12 +206,13 @@ class MSTD(MSTD):
 
         fig = self_col.mstd.vbt.plot(
             trace_kwargs=mstd_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
 
         return fig
 
 
-fix_class_for_docs(MSTD)
+setattr(MSTD, '__doc__', _MSTD.__doc__)
+setattr(MSTD, 'plot', _MSTD.plot)
 
 # ############# BBANDS ############# #
 
@@ -203,7 +224,7 @@ BBANDS = IndicatorFactory(
     input_names=['close'],
     param_names=['window', 'ewm', 'alpha'],
     output_names=['middle', 'upper', 'lower'],
-    custom_output_funcs=dict(
+    custom_output_props=dict(
         percent_b=lambda self: self.wrapper.wrap(
             (self.close.values - self.lower.values) / (self.upper.values - self.lower.values)),
         bandwidth=lambda self: self.wrapper.wrap(
@@ -212,22 +233,23 @@ BBANDS = IndicatorFactory(
 ).from_apply_func(
     nb.bb_apply_nb,
     cache_func=nb.bb_cache_nb,
+    kwargs_to_args=['adjust', 'ddof'],
     window=20,
     ewm=False,
-    alpha=2
+    alpha=2,
+    adjust=False,
+    ddof=0
 )
 
 
-class BBANDS(BBANDS):
+class _BBANDS(BBANDS):
     """Bollinger Bands (BBANDS).
 
     A Bollinger Band® is a technical analysis tool defined by a set of lines plotted two standard
     deviations (positively and negatively) away from a simple moving average (SMA) of the security's
     price, but can be adjusted to user preferences.
 
-    See [Bollinger Band®](https://www.investopedia.com/terms/b/bollingerbands.asp).
-
-    Use `BBANDS.run` or `BBANDS.run_combs` to run the indicator."""
+    See [Bollinger Band®](https://www.investopedia.com/terms/b/bollingerbands.asp)."""
 
     def plot(self,
              column=None,
@@ -236,7 +258,7 @@ class BBANDS(BBANDS):
              middle_trace_kwargs=None,
              upper_trace_kwargs=None,
              lower_trace_kwargs=None,
-             row=None, col=None,
+             add_trace_kwargs=None,
              fig=None,
              **layout_kwargs):  # pragma: no cover
         """Plot `BBANDS.middle`, `BBANDS.upper` and `BBANDS.lower` against
@@ -249,15 +271,14 @@ class BBANDS(BBANDS):
             middle_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `BBANDS.middle`.
             upper_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `BBANDS.upper`.
             lower_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `BBANDS.lower`.
-            row (int): Row position.
-            col (int): Column position.
+            add_trace_kwargs (dict): Keyword arguments passed to `add_trace`.
             fig (plotly.graph_objects.Figure): Figure to add traces to.
             **layout_kwargs: Keyword arguments for layout.
 
         ## Example
 
         ```python-repl
-        >>> vbt.BBANDS.run(price['Close']).plot()
+        >>> vbt.BBANDS.run(ohlcv['Close']).plot()
         ```
 
         ![](/vectorbt/docs/img/BBANDS.png)
@@ -267,7 +288,7 @@ class BBANDS(BBANDS):
         self_col = self.select_series(column=column)
 
         if fig is None:
-            fig = CustomFigureWidget()
+            fig = FigureWidget()
         fig.update_layout(**layout_kwargs)
 
         if close_trace_kwargs is None:
@@ -298,22 +319,23 @@ class BBANDS(BBANDS):
 
         fig = self_col.lower.vbt.plot(
             trace_kwargs=lower_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
         fig = self_col.upper.vbt.plot(
             trace_kwargs=upper_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
         fig = self_col.middle.vbt.plot(
             trace_kwargs=middle_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
         if plot_close:
             fig = self_col.close.vbt.plot(
                 trace_kwargs=close_trace_kwargs,
-                row=row, col=col, fig=fig)
+                add_trace_kwargs=add_trace_kwargs, fig=fig)
 
         return fig
 
 
-fix_class_for_docs(BBANDS)
+setattr(BBANDS, '__doc__', _BBANDS.__doc__)
+setattr(BBANDS, 'plot', _BBANDS.plot)
 
 # ############# RSI ############# #
 
@@ -328,12 +350,14 @@ RSI = IndicatorFactory(
 ).from_apply_func(
     nb.rsi_apply_nb,
     cache_func=nb.rsi_cache_nb,
+    kwargs_to_args=['adjust'],
     window=14,
-    ewm=False
+    ewm=False,
+    adjust=False
 )
 
 
-class RSI(RSI):
+class _RSI(RSI):
     """Relative Strength Index (RSI).
 
     Compares the magnitude of recent gains and losses over a specified time
@@ -341,15 +365,13 @@ class RSI(RSI):
     primarily used to attempt to identify overbought or oversold conditions in
     the trading of an asset.
 
-    See [Relative Strength Index (RSI)](https://www.investopedia.com/terms/r/rsi.asp).
-
-    Use `RSI.run` or `RSI.run_combs` to run the indicator."""
+    See [Relative Strength Index (RSI)](https://www.investopedia.com/terms/r/rsi.asp)."""
 
     def plot(self,
              column=None,
              levels=(30, 70),
              rsi_trace_kwargs=None,
-             row=None, col=None,
+             add_trace_kwargs=None,
              xref='x', yref='y',
              fig=None,
              **layout_kwargs):  # pragma: no cover
@@ -359,8 +381,7 @@ class RSI(RSI):
             column (str): Name of the column to plot.
             levels (tuple): Two extremes: bottom and top.
             rsi_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `RSI.rsi`.
-            row (int): Row position.
-            col (int): Column position.
+            add_trace_kwargs (dict): Keyword arguments passed to `add_trace`.
             xref (str): X coordinate axis.
             yref (str): Y coordinate axis.
             fig (plotly.graph_objects.Figure): Figure to add traces to.
@@ -369,7 +390,7 @@ class RSI(RSI):
         ## Example
 
         ```python-repl
-        >>> vbt.RSI.run(price['Close']).plot()
+        >>> vbt.RSI.run(ohlcv['Close']).plot()
         ```
 
         ![](/vectorbt/docs/img/RSI.png)
@@ -377,7 +398,7 @@ class RSI(RSI):
         self_col = self.select_series(column=column)
 
         if fig is None:
-            fig = CustomFigureWidget()
+            fig = FigureWidget()
         default_layout = dict()
         default_layout['yaxis' + yref[1:]] = dict(range=[-5, 105])
         fig.update_layout(**default_layout)
@@ -391,7 +412,7 @@ class RSI(RSI):
 
         fig = self_col.rsi.vbt.plot(
             trace_kwargs=rsi_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
 
         # Fill void between levels
         fig.add_shape(
@@ -411,7 +432,8 @@ class RSI(RSI):
         return fig
 
 
-fix_class_for_docs(RSI)
+setattr(RSI, '__doc__', _RSI.__doc__)
+setattr(RSI, 'plot', _RSI.plot)
 
 # ############# STOCH ############# #
 
@@ -426,22 +448,22 @@ STOCH = IndicatorFactory(
 ).from_apply_func(
     nb.stoch_apply_nb,
     cache_func=nb.stoch_cache_nb,
+    kwargs_to_args=['adjust'],
     k_window=14,
     d_window=3,
-    d_ewm=False
+    d_ewm=False,
+    adjust=False
 )
 
 
-class STOCH(STOCH):
+class _STOCH(STOCH):
     """Stochastic Oscillator (STOCH).
 
     A stochastic oscillator is a momentum indicator comparing a particular closing price
     of a security to a range of its prices over a certain period of time. It is used to
     generate overbought and oversold trading signals, utilizing a 0-100 bounded range of values.
 
-    See [Stochastic Oscillator](https://www.investopedia.com/terms/s/stochasticoscillator.asp).
-
-    Use `STOCH.run` or `STOCH.run_combs` to run the indicator."""
+    See [Stochastic Oscillator](https://www.investopedia.com/terms/s/stochasticoscillator.asp)."""
 
     def plot(self,
              column=None,
@@ -449,7 +471,7 @@ class STOCH(STOCH):
              percent_k_trace_kwargs=None,
              percent_d_trace_kwargs=None,
              shape_kwargs=None,
-             row=None, col=None,
+             add_trace_kwargs=None,
              xref='x', yref='y',
              fig=None,
              **layout_kwargs):  # pragma: no cover
@@ -461,8 +483,7 @@ class STOCH(STOCH):
             percent_k_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `STOCH.percent_k`.
             percent_d_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `STOCH.percent_d`.
             shape_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Figure.add_shape` for zone between levels.
-            row (int): Row position.
-            col (int): Column position.
+            add_trace_kwargs (dict): Keyword arguments passed to `add_trace`.
             xref (str): X coordinate axis.
             yref (str): Y coordinate axis.
             fig (plotly.graph_objects.Figure): Figure to add traces to.
@@ -471,7 +492,7 @@ class STOCH(STOCH):
         ## Example
 
         ```python-repl
-        >>> vbt.STOCH.run(price['High'], price['Low'], price['Close']).plot()
+        >>> vbt.STOCH.run(ohlcv['High'], ohlcv['Low'], ohlcv['Close']).plot()
         ```
 
         ![](/vectorbt/docs/img/STOCH.png)
@@ -479,7 +500,7 @@ class STOCH(STOCH):
         self_col = self.select_series(column=column)
 
         if fig is None:
-            fig = CustomFigureWidget()
+            fig = FigureWidget()
         default_layout = dict()
         default_layout['yaxis' + yref[1:]] = dict(range=[-5, 105])
         fig.update_layout(**default_layout)
@@ -500,10 +521,10 @@ class STOCH(STOCH):
 
         fig = self_col.percent_k.vbt.plot(
             trace_kwargs=percent_k_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
         fig = self_col.percent_d.vbt.plot(
             trace_kwargs=percent_d_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
 
         # Plot levels
         # Fill void between levels
@@ -525,7 +546,8 @@ class STOCH(STOCH):
         return fig
 
 
-fix_class_for_docs(STOCH)
+setattr(STOCH, '__doc__', _STOCH.__doc__)
+setattr(STOCH, 'plot', _STOCH.plot)
 
 # ############# MACD ############# #
 
@@ -537,36 +559,36 @@ MACD = IndicatorFactory(
     input_names=['close'],
     param_names=['fast_window', 'slow_window', 'signal_window', 'macd_ewm', 'signal_ewm'],
     output_names=['macd', 'signal'],
-    custom_output_funcs=dict(
+    custom_output_props=dict(
         hist=lambda self: self.wrapper.wrap(self.macd.values - self.signal.values),
     )
 ).from_apply_func(
     nb.macd_apply_nb,
     cache_func=nb.macd_cache_nb,
+    kwargs_to_args=['adjust'],
     fast_window=12,
     slow_window=26,
     signal_window=9,
     macd_ewm=False,
-    signal_ewm=False
+    signal_ewm=False,
+    adjust=False
 )
 
 
-class MACD(MACD):
+class _MACD(MACD):
     """Moving Average Convergence Divergence (MACD).
 
     Is a trend-following momentum indicator that shows the relationship between
     two moving averages of prices.
 
-    See [Moving Average Convergence Divergence – MACD](https://www.investopedia.com/terms/m/macd.asp).
-
-    Use `MACD.run` or `MACD.run_combs` to run the indicator."""
+    See [Moving Average Convergence Divergence – MACD](https://www.investopedia.com/terms/m/macd.asp)."""
 
     def plot(self,
              column=None,
              macd_trace_kwargs=None,
              signal_trace_kwargs=None,
              hist_trace_kwargs=None,
-             row=None, col=None,
+             add_trace_kwargs=None,
              fig=None,
              **layout_kwargs):  # pragma: no cover
         """Plot `MACD.macd`, `MACD.signal` and `MACD.hist`.
@@ -576,22 +598,21 @@ class MACD(MACD):
             macd_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `MACD.macd`.
             signal_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `MACD.signal`.
             hist_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Bar` for `MACD.hist`.
-            row (int): Row position.
-            col (int): Column position.
+            add_trace_kwargs (dict): Keyword arguments passed to `add_trace`.
             fig (plotly.graph_objects.Figure): Figure to add traces to.
             **layout_kwargs: Keyword arguments for layout.
 
         ## Example
 
         ```python-repl
-        >>> vbt.MACD.run(price['Close']).plot()
+        >>> vbt.MACD.run(ohlcv['Close']).plot()
         ```
 
         ![](/vectorbt/docs/img/MACD.png)"""
         self_col = self.select_series(column=column)
 
         if fig is None:
-            fig = CustomFigureWidget()
+            fig = FigureWidget()
             fig.update_layout(bargap=0)
         fig.update_layout(**layout_kwargs)
 
@@ -611,10 +632,10 @@ class MACD(MACD):
 
         fig = self_col.macd.vbt.plot(
             trace_kwargs=macd_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
         fig = self_col.signal.vbt.plot(
             trace_kwargs=signal_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
 
         # Plot hist
         hist = self_col.hist.values
@@ -632,12 +653,15 @@ class MACD(MACD):
             marker_line_width=0
         )
         hist_bar.update(**hist_trace_kwargs)
-        fig.add_trace(hist_bar, row=row, col=col)
+        if add_trace_kwargs is None:
+            add_trace_kwargs = {}
+        fig.add_trace(hist_bar, **add_trace_kwargs)
 
         return fig
 
 
-fix_class_for_docs(MACD)
+setattr(MACD, '__doc__', _MACD.__doc__)
+setattr(MACD, 'plot', _MACD.plot)
 
 # ############# ATR ############# #
 
@@ -652,12 +676,14 @@ ATR = IndicatorFactory(
 ).from_apply_func(
     nb.atr_apply_nb,
     cache_func=nb.atr_cache_nb,
+    kwargs_to_args=['adjust'],
     window=14,
-    ewm=True
+    ewm=True,
+    adjust=False
 )
 
 
-class ATR(ATR):
+class _ATR(ATR):
     """Average True Range (ATR).
 
     The indicator provide an indication of the degree of price volatility.
@@ -666,8 +692,6 @@ class ATR(ATR):
 
     See [Average True Range - ATR](https://www.investopedia.com/terms/a/atr.asp).
 
-    Use `ATR.run` or `ATR.run_combs` to run the indicator.
-
     !!! note
         Uses Simple MA and Exponential MA as compared to Wilder.
     """
@@ -676,7 +700,7 @@ class ATR(ATR):
              column=None,
              tr_trace_kwargs=None,
              atr_trace_kwargs=None,
-             row=None, col=None,
+             add_trace_kwargs=None,
              fig=None,
              **layout_kwargs):  # pragma: no cover
         """Plot `ATR.tr` and `ATR.atr`.
@@ -685,15 +709,14 @@ class ATR(ATR):
             column (str): Name of the column to plot.
             tr_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `ATR.tr`.
             atr_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `ATR.atr`.
-            row (int): Row position.
-            col (int): Column position.
+            add_trace_kwargs (dict): Keyword arguments passed to `add_trace`.
             fig (plotly.graph_objects.Figure): Figure to add traces to.
             **layout_kwargs: Keyword arguments for layout.
 
         ## Example
 
         ```python-repl
-        >>> vbt.ATR.run(price['High'], price['Low'], price['Close'], 10).plot()
+        >>> vbt.ATR.run(ohlcv['High'], ohlcv['Low'], ohlcv['Close'], 10).plot()
         ```
 
         ![](/vectorbt/docs/img/ATR.png)
@@ -701,7 +724,7 @@ class ATR(ATR):
         self_col = self.select_series(column=column)
 
         if fig is None:
-            fig = CustomFigureWidget()
+            fig = FigureWidget()
         fig.update_layout(**layout_kwargs)
 
         if tr_trace_kwargs is None:
@@ -717,15 +740,16 @@ class ATR(ATR):
 
         fig = self_col.tr.vbt.plot(
             trace_kwargs=tr_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
         fig = self_col.atr.vbt.plot(
             trace_kwargs=atr_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
 
         return fig
 
 
-fix_class_for_docs(ATR)
+setattr(ATR, '__doc__', _ATR.__doc__)
+setattr(ATR, 'plot', _ATR.plot)
 
 # ############# OBV ############# #
 
@@ -740,19 +764,17 @@ OBV = IndicatorFactory(
 ).from_custom_func(nb.obv_custom_nb)
 
 
-class OBV(OBV):
+class _OBV(OBV):
     """On-balance volume (OBV).
 
     It relates price and volume in the stock market. OBV is based on a cumulative total volume.
 
-    See [On-Balance Volume (OBV)](https://www.investopedia.com/terms/o/onbalancevolume.asp).
-
-    Use `OBV.run` to run the indicator."""
+    See [On-Balance Volume (OBV)](https://www.investopedia.com/terms/o/onbalancevolume.asp)."""
 
     def plot(self,
              column=None,
              obv_trace_kwargs=None,
-             row=None, col=None,
+             add_trace_kwargs=None,
              fig=None,
              **layout_kwargs):  # pragma: no cover
         """Plot `OBV.obv`.
@@ -760,15 +782,14 @@ class OBV(OBV):
         Args:
             column (str): Name of the column to plot.
             obv_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for `OBV.obv`.
-            row (int): Row position.
-            col (int): Column position.
+            add_trace_kwargs (dict): Keyword arguments passed to `add_trace`.
             fig (plotly.graph_objects.Figure): Figure to add traces to.
             **layout_kwargs: Keyword arguments for layout.
 
         ## Example
 
         ```py
-        >>> vbt.OBV.run(price['Close'], price['Volume']).plot()
+        >>> vbt.OBV.run(ohlcv['Close'], ohlcv['Volume']).plot()
         ```
 
         ![](/vectorbt/docs/img/OBV.png)
@@ -776,7 +797,7 @@ class OBV(OBV):
         self_col = self.select_series(column=column)
 
         if fig is None:
-            fig = CustomFigureWidget()
+            fig = FigureWidget()
         fig.update_layout(**layout_kwargs)
 
         if obv_trace_kwargs is None:
@@ -787,9 +808,10 @@ class OBV(OBV):
 
         fig = self_col.obv.vbt.plot(
             trace_kwargs=obv_trace_kwargs,
-            row=row, col=col, fig=fig)
+            add_trace_kwargs=add_trace_kwargs, fig=fig)
 
         return fig
 
 
-fix_class_for_docs(OBV)
+setattr(OBV, '__doc__', _OBV.__doc__)
+setattr(OBV, 'plot', _OBV.plot)
