@@ -1,5 +1,13 @@
 """Base class for working with trade records.
 
+Class `Trades` wraps trade records and the corresponding time series
+(such as open or close) to analyze trades. Use `vectorbt.portfolio.trades.Trades.from_orders`
+to generate trade records from order records. This is done automatically in the
+`vectorbt.portfolio.base.Portfolio` class, available as `vectorbt.portfolio.base.Portfolio.trades`.
+
+Class `Positions` has the same properties as trades and is also
+provided by `vectorbt.portfolio.base.Portfolio` as `vectorbt.portfolio.base.Portfolio.positions`.
+
 !!! warning
     Both record types return both closed AND open trades, which may skew your performance results.
     To only consider closed trades, you should explicitly query `closed` attribute."""
@@ -13,7 +21,7 @@ from vectorbt.utils.decorators import cached_property, cached_method
 from vectorbt.utils.config import merge_dicts
 from vectorbt.utils.datetime import DatetimeTypes
 from vectorbt.utils.enum import to_value_map
-from vectorbt.utils.widgets import CustomFigureWidget
+from vectorbt.utils.widgets import FigureWidget
 from vectorbt.utils.array import min_rel_rescale, max_rel_rescale
 from vectorbt.base.reshape_fns import to_1d, to_2d, broadcast_to
 from vectorbt.records.base import Records
@@ -143,10 +151,10 @@ class Trades(Records):
             if not all(field in records_arr.dtype.names for field in position_dt.names):
                 raise TypeError("Records array must match position_dt")
 
-    def _indexing_func_meta(self, pd_indexing_func):
+    def _indexing_func_meta(self, pd_indexing_func, **kwargs):
         """Perform indexing on `Trades` and also return metadata."""
         new_wrapper, new_records_arr, group_idxs, col_idxs = \
-            Records._indexing_func_meta(self, pd_indexing_func)
+            Records._indexing_func_meta(self, pd_indexing_func, **kwargs)
         new_close = new_wrapper.wrap(to_2d(self.close, raw=True)[:, col_idxs], group_by=False)
         return self.copy(
             wrapper=new_wrapper,
@@ -154,9 +162,9 @@ class Trades(Records):
             close=new_close
         ), group_idxs, col_idxs
 
-    def _indexing_func(self, pd_indexing_func):
+    def _indexing_func(self, pd_indexing_func, **kwargs):
         """Perform indexing on `Trades`."""
-        return self._indexing_func_meta(pd_indexing_func)[0]
+        return self._indexing_func_meta(pd_indexing_func, **kwargs)[0]
 
     @property
     def close(self):
@@ -225,11 +233,12 @@ class Trades(Records):
         return self.filter_by_mask(filter_mask)
 
     @cached_method
-    def win_rate(self, group_by=None, **kwargs):
+    def win_rate(self, group_by=None, wrap_kwargs=None):
         """Rate of winning trades."""
         win_count = to_1d(self.winning.count(group_by=group_by), raw=True)
         total_count = to_1d(self.count(group_by=group_by), raw=True)
-        return self.wrapper.wrap_reduced(win_count / total_count, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='win_rate'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(win_count / total_count, group_by=group_by, **wrap_kwargs)
 
     @cached_property
     def losing(self):
@@ -238,14 +247,15 @@ class Trades(Records):
         return self.filter_by_mask(filter_mask)
 
     @cached_method
-    def loss_rate(self, group_by=None, **kwargs):
+    def loss_rate(self, group_by=None, wrap_kwargs=None):
         """Rate of losing trades."""
         loss_count = to_1d(self.losing.count(group_by=group_by), raw=True)
         total_count = to_1d(self.count(group_by=group_by), raw=True)
-        return self.wrapper.wrap_reduced(loss_count / total_count, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='loss_rate'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(loss_count / total_count, group_by=group_by, **wrap_kwargs)
 
     @cached_method
-    def profit_factor(self, group_by=None, **kwargs):
+    def profit_factor(self, group_by=None, wrap_kwargs=None):
         """Profit factor."""
         total_win = to_1d(self.winning.pnl.sum(group_by=group_by), raw=True)
         total_loss = to_1d(self.losing.pnl.sum(group_by=group_by), raw=True)
@@ -256,10 +266,11 @@ class Trades(Records):
         total_loss[np.isnan(total_loss) & has_values] = 0.
 
         profit_factor = total_win / np.abs(total_loss)
-        return self.wrapper.wrap_reduced(profit_factor, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='profit_factor'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(profit_factor, group_by=group_by, **wrap_kwargs)
 
     @cached_method
-    def expectancy(self, group_by=None, **kwargs):
+    def expectancy(self, group_by=None, wrap_kwargs=None):
         """Average profitability."""
         win_rate = to_1d(self.win_rate(group_by=group_by), raw=True)
         avg_win = to_1d(self.winning.pnl.mean(group_by=group_by), raw=True)
@@ -271,16 +282,18 @@ class Trades(Records):
         avg_loss[np.isnan(avg_loss) & has_values] = 0.
 
         expectancy = win_rate * avg_win - (1 - win_rate) * np.abs(avg_loss)
-        return self.wrapper.wrap_reduced(expectancy, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='expectancy'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(expectancy, group_by=group_by, **wrap_kwargs)
 
     @cached_method
-    def sqn(self, group_by=None, **kwargs):
+    def sqn(self, group_by=None, wrap_kwargs=None):
         """System Quality Number (SQN)."""
         count = to_1d(self.count(group_by=group_by), raw=True)
         pnl_mean = to_1d(self.pnl.mean(group_by=group_by), raw=True)
         pnl_std = to_1d(self.pnl.std(group_by=group_by), raw=True)
         sqn = np.sqrt(count) * pnl_mean / pnl_std
-        return self.wrapper.wrap_reduced(sqn, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='sqn'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(sqn, group_by=group_by, **wrap_kwargs)
 
     # ############# TradeDirection ############# #
 
@@ -296,11 +309,12 @@ class Trades(Records):
         return self.filter_by_mask(filter_mask)
 
     @cached_method
-    def long_rate(self, group_by=None, **kwargs):
+    def long_rate(self, group_by=None, wrap_kwargs=None):
         """Rate of long trades."""
         long_count = to_1d(self.long.count(group_by=group_by), raw=True)
         total_count = to_1d(self.count(group_by=group_by), raw=True)
-        return self.wrapper.wrap_reduced(long_count / total_count, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='long_rate'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(long_count / total_count, group_by=group_by, **wrap_kwargs)
 
     @cached_property
     def short(self):
@@ -309,11 +323,12 @@ class Trades(Records):
         return self.filter_by_mask(filter_mask)
 
     @cached_method
-    def short_rate(self, group_by=None, **kwargs):
+    def short_rate(self, group_by=None, wrap_kwargs=None):
         """Rate of short trades."""
         short_count = to_1d(self.short.count(group_by=group_by), raw=True)
         total_count = to_1d(self.count(group_by=group_by), raw=True)
-        return self.wrapper.wrap_reduced(short_count / total_count, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='short_rate'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(short_count / total_count, group_by=group_by, **wrap_kwargs)
 
     # ############# TradeStatus ############# #
 
@@ -329,11 +344,12 @@ class Trades(Records):
         return self.filter_by_mask(filter_mask)
 
     @cached_method
-    def open_rate(self, group_by=None, **kwargs):
+    def open_rate(self, group_by=None, wrap_kwargs=None):
         """Rate of open trades."""
         open_count = to_1d(self.open.count(group_by=group_by), raw=True)
         total_count = to_1d(self.count(group_by=group_by), raw=True)
-        return self.wrapper.wrap_reduced(open_count / total_count, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='open_rate'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(open_count / total_count, group_by=group_by, **wrap_kwargs)
 
     @cached_property
     def closed(self):
@@ -342,23 +358,24 @@ class Trades(Records):
         return self.filter_by_mask(filter_mask)
 
     @cached_method
-    def closed_rate(self, group_by=None, **kwargs):
+    def closed_rate(self, group_by=None, wrap_kwargs=None):
         """Rate of closed trades."""
         closed_count = to_1d(self.closed.count(group_by=group_by), raw=True)
         total_count = to_1d(self.count(group_by=group_by), raw=True)
-        return self.wrapper.wrap_reduced(closed_count / total_count, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='closed_rate'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(closed_count / total_count, group_by=group_by, **wrap_kwargs)
 
     # ############# Plotting ############# #
 
     def plot_pnl(self,
                  column=None,
-                 marker_size_range=[7, 14],
-                 opacity_range=[0.75, 0.9],
+                 marker_size_range=(7, 14),
+                 opacity_range=(0.75, 0.9),
                  closed_profit_trace_kwargs=None,
                  closed_loss_trace_kwargs=None,
                  open_trace_kwargs=None,
                  hline_shape_kwargs=None,
-                 row=None, col=None,
+                 add_trace_kwargs=None,
                  xref='x', yref='y',
                  fig=None,
                  **layout_kwargs):  # pragma: no cover
@@ -366,12 +383,13 @@ class Trades(Records):
 
         Args:
             column (str): Name of the column to plot.
+            marker_size_range (tuple): Range of marker size.
+            opacity_range (tuple): Range of marker opacity.
             closed_profit_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for "Closed - Profit" markers.
             closed_loss_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for "Closed - Loss" markers.
             open_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for "Open" markers.
             hline_shape_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Figure.add_shape` for zeroline.
-            row (int): Row position.
-            col (int): Column position.
+            add_trace_kwargs (dict): Keyword arguments passed to `add_trace`.
             xref (str): X coordinate axis.
             yref (str): Y coordinate axis.
             fig (plotly.graph_objects.Figure): Figure to add traces to.
@@ -389,7 +407,6 @@ class Trades(Records):
 
         self_col = self.select_series(column=column, group_by=False)
 
-
         if closed_profit_trace_kwargs is None:
             closed_profit_trace_kwargs = {}
         if closed_loss_trace_kwargs is None:
@@ -398,10 +415,12 @@ class Trades(Records):
             open_trace_kwargs = {}
         if hline_shape_kwargs is None:
             hline_shape_kwargs = {}
+        if add_trace_kwargs is None:
+            add_trace_kwargs = {}
         marker_size_range = tuple(marker_size_range)
 
         if fig is None:
-            fig = CustomFigureWidget()
+            fig = FigureWidget()
         fig.update_layout(**layout_kwargs)
         x_domain = [0, 1]
         xaxis = 'xaxis' + xref[1:]
@@ -455,7 +474,7 @@ class Trades(Records):
                                             "<br>Return: %{customdata[1]:.2%}"
                 )
                 profit_scatter.update(**closed_profit_trace_kwargs)
-                fig.add_trace(profit_scatter, row=row, col=col)
+                fig.add_trace(profit_scatter, **add_trace_kwargs)
 
             if np.any(closed_loss_mask):
                 # Plot Loss markers
@@ -481,7 +500,7 @@ class Trades(Records):
                                             "<br>Return: %{customdata[1]:.2%}"
                 )
                 loss_scatter.update(**closed_loss_trace_kwargs)
-                fig.add_trace(loss_scatter, row=row, col=col)
+                fig.add_trace(loss_scatter, **add_trace_kwargs)
 
             if np.any(open_mask):
                 # Plot Active markers
@@ -507,7 +526,7 @@ class Trades(Records):
                                             "<br>Return: %{customdata[1]:.2%}"
                 )
                 active_scatter.update(**open_trace_kwargs)
-                fig.add_trace(active_scatter, row=row, col=col)
+                fig.add_trace(active_scatter, **add_trace_kwargs)
 
         # Plot zeroline
         fig.add_shape(**merge_dicts(dict(
@@ -537,7 +556,7 @@ class Trades(Records):
              active_trace_kwargs=None,
              profit_shape_kwargs=None,
              loss_shape_kwargs=None,
-             row=None, col=None,
+             add_trace_kwargs=None,
              xref='x', yref='y',
              fig=None,
              **layout_kwargs):  # pragma: no cover
@@ -557,8 +576,7 @@ class Trades(Records):
             active_trace_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Scatter` for "Active" markers.
             profit_shape_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Figure.add_shape` for profit zones.
             loss_shape_kwargs (dict): Keyword arguments passed to `plotly.graph_objects.Figure.add_shape` for loss zones.
-            row (int): Row position.
-            col (int): Column position.
+            add_trace_kwargs (dict): Keyword arguments passed to `add_trace`.
             xref (str): X coordinate axis.
             yref (str): Y coordinate axis.
             fig (plotly.graph_objects.Figure): Figure to add traces to.
@@ -595,14 +613,16 @@ class Trades(Records):
             profit_shape_kwargs = {}
         if loss_shape_kwargs is None:
             loss_shape_kwargs = {}
+        if add_trace_kwargs is None:
+            add_trace_kwargs = {}
 
         if fig is None:
-            fig = CustomFigureWidget()
+            fig = FigureWidget()
         fig.update_layout(**layout_kwargs)
 
         # Plot close
         if plot_close:
-            fig = self_col.close.vbt.plot(trace_kwargs=close_trace_kwargs, row=row, col=col, fig=fig)
+            fig = self_col.close.vbt.plot(trace_kwargs=close_trace_kwargs, add_trace_kwargs=add_trace_kwargs, fig=fig)
 
         if len(self_col.values) > 0:
             # Extract information
@@ -668,7 +688,7 @@ class Trades(Records):
                                      if self.trade_type == TradeType.Trade else '')
                 )
                 entry_scatter.update(**entry_trace_kwargs)
-                fig.add_trace(entry_scatter, row=row, col=col)
+                fig.add_trace(entry_scatter, **add_trace_kwargs)
 
             # Plot end markers
             def _plot_end_markers(mask, name, color, kwargs):
@@ -712,7 +732,7 @@ class Trades(Records):
                                          if self.trade_type == TradeType.Trade else '')
                     )
                     scatter.update(**kwargs)
-                    fig.add_trace(scatter, row=row, col=col)
+                    fig.add_trace(scatter, **add_trace_kwargs)
 
             # Plot Exit markers
             _plot_end_markers(
@@ -862,8 +882,9 @@ class Positions(Trades):
         return cls(trades.wrapper, position_records_arr, trades.close, **kwargs)
 
     @cached_method
-    def coverage(self, group_by=None, **kwargs):
+    def coverage(self, group_by=None, wrap_kwargs=None):
         """Coverage, that is, total duration divided by the whole period."""
         total_duration = to_1d(self.duration.sum(group_by=group_by), raw=True)
         total_steps = self.wrapper.grouper.get_group_lens(group_by=group_by) * self.wrapper.shape[0]
-        return self.wrapper.wrap_reduced(total_duration / total_steps, group_by=group_by, **kwargs)
+        wrap_kwargs = merge_dicts(dict(name_or_index='coverage'), wrap_kwargs)
+        return self.wrapper.wrap_reduced(total_duration / total_steps, group_by=group_by, **wrap_kwargs)
