@@ -1,4 +1,7 @@
-"""Numba-compiled 1-dim and 2-dim functions.
+"""Numba-compiled functions.
+
+Provides an arsenal of Numba-compiled functions for records and mapped arrays.
+These only accept NumPy arrays and other Numba-compatible types.
 
 !!! note
     vectorbt treats matrices as first-class citizens and expects input arrays to be
