@@ -1,4 +1,17 @@
-"""Numba-compiled 1-dim and 2-dim functions.
+"""Numba-compiled functions.
+
+Provides an arsenal of Numba-compiled functions that are used by accessors
+and in many other parts of the backtesting pipeline, such as technical indicators.
+These only accept NumPy arrays and other Numba-compatible types.
+
+```python-repl
+>>> import numpy as np
+>>> import vectorbt as vbt
+
+>>> # vectorbt.signals.nb.rank_1d_nb
+>>> vbt.signals.nb.rank_1d_nb(np.array([False, True, True, True, False]))
+array([0, 1, 2, 3, 0])
+```
 
 !!! note
     vectorbt treats matrices as first-class citizens and expects input arrays to be
@@ -17,7 +30,7 @@ from vectorbt.base.reshape_fns import flex_select_auto_nb
 from vectorbt.signals.enums import StopType
 
 
-# ############# Signal generation ############# #
+# ############# Generation ############# #
 
 
 @njit
@@ -142,6 +155,44 @@ def generate_enex_nb(shape, entry_wait, exit_wait, entry_choice_func_nb,
     return entries, exits
 
 
+# ############# Filtering ############# #
+
+
+@njit(cache=True)
+def clean_enex_1d_nb(entries, exits, entry_first):
+    """Clean entry and exit arrays by picking the first signal out of each.
+
+    Entry signal must be picked first. If both signals are present, selects none."""
+    entries_out = np.full(entries.shape, False, dtype=np.bool_)
+    exits_out = np.full(entries.shape, False, dtype=np.bool_)
+
+    phase = -1
+    for i in range(entries.shape[0]):
+        if entries[i] and exits[i]:
+            continue
+        if entries[i]:
+            if phase == -1 or phase == 0:
+                phase = 1
+                entries_out[i] = True
+        if exits[i]:
+            if (not entry_first and phase == -1) or phase == 1:
+                phase = 0
+                exits_out[i] = True
+
+    return entries_out, exits_out
+
+
+@njit(cache=True)
+def clean_enex_nb(entries, exits, entry_first):
+    """2-dim version of `clean_enex_1d_nb`."""
+    entries_out = np.empty(entries.shape, dtype=np.bool_)
+    exits_out = np.empty(entries.shape, dtype=np.bool_)
+
+    for col in range(entries.shape[1]):
+        entries_out[:, col], exits_out[:, col] = clean_enex_1d_nb(entries[:, col], exits[:, col], entry_first)
+    return entries_out, exits_out
+
+
 # ############# Random ############# #
 
 
@@ -354,7 +405,7 @@ def first_choice_nb(from_i, to_i, col, a):
 
 @njit(cache=True)
 def stop_choice_nb(from_i, to_i, col, ts, stop, trailing, wait, first, temp_idx_arr, flex_2d):
-    """`choice_func_nb` that returns the indices of the stop being reached.
+    """`choice_func_nb` that returns the indices of the stop being hit.
 
     Args:
         col (int): Current column.
@@ -468,9 +519,9 @@ def generate_stop_ex_iter_nb(entries, ts, stop, trailing, entry_wait, exit_wait,
 
 
 @njit(cache=True)
-def adv_stop_choice_nb(from_i, to_i, col, open, high, low, close, hit_price_out, stop_type_out,
-                       sl_stop, ts_stop, tp_stop, is_open_safe, wait, first, temp_idx_arr, flex_2d):
-    """`choice_func_nb` that returns the indices of the stop price being reached.
+def ohlc_stop_choice_nb(from_i, to_i, col, open, high, low, close, hit_price_out, stop_type_out,
+                        sl_stop, ts_stop, tp_stop, is_open_safe, wait, first, temp_idx_arr, flex_2d):
+    """`choice_func_nb` that returns the indices of the stop price being hit within OHLC.
 
     Compared to `stop_choice_nb`, takes into account the whole bar, can check for both
     (trailing) stop loss and take profit simultaneously, and tracks hit price and stop type.
@@ -578,9 +629,9 @@ def adv_stop_choice_nb(from_i, to_i, col, open, high, low, close, hit_price_out,
 
 
 @njit
-def generate_adv_stop_ex_nb(entries, open, high, low, close, hit_price_out, stop_type_out,
-                            sl_stop, ts_stop, tp_stop, is_open_safe, wait, first, flex_2d):
-    """Generate using `generate_ex_nb` and `adv_stop_choice_nb`.
+def generate_ohlc_stop_ex_nb(entries, open, high, low, close, hit_price_out, stop_type_out,
+                             sl_stop, ts_stop, tp_stop, is_open_safe, wait, first, flex_2d):
+    """Generate using `generate_ex_nb` and `ohlc_stop_choice_nb`.
 
     ## Example
 
@@ -588,7 +639,7 @@ def generate_adv_stop_ex_nb(entries, open, high, low, close, hit_price_out, stop
     Illustrates how exit signal can be generated within the same tick as entry.
     ```python-repl
     >>> import numpy as np
-    >>> from vectorbt.signals.nb import generate_adv_stop_ex_nb
+    >>> from vectorbt.signals.nb import generate_ohlc_stop_ex_nb
 
     >>> entries = np.asarray([True, False, False, False, False])[:, None]
     >>> open_p = np.asarray([10, 11, 12, 11, 10])[:, None]
@@ -604,7 +655,7 @@ def generate_adv_stop_ex_nb(entries, open, high, low, close, hit_price_out, stop
     >>> first = True
     >>> flex_2d = True
 
-    >>> generate_adv_stop_ex_nb(
+    >>> generate_ohlc_stop_ex_nb(
     ...     entries, open_p, high_p, low_p, close_p,
     ...     hit_p_out, stop_type_out, sl_stop, tp_stop, tp_stop,
     ...     is_entry_p_safe, 0, first, flex_2d)
@@ -631,17 +682,17 @@ def generate_adv_stop_ex_nb(entries, open, high, low, close, hit_price_out, stop
     """
     temp_idx_arr = np.empty((entries.shape[0],), dtype=np.int_)
     return generate_ex_nb(
-        entries, wait, adv_stop_choice_nb,
+        entries, wait, ohlc_stop_choice_nb,
         open, high, low, close, hit_price_out, stop_type_out,
         sl_stop, ts_stop, tp_stop, is_open_safe, wait, first, temp_idx_arr, flex_2d
     )
 
 
 @njit
-def generate_adv_stop_ex_iter_nb(entries, open, high, low, close, hit_price_out, stop_type_out,
-                                 sl_stop, ts_stop, tp_stop, is_open_safe, entry_wait,
-                                 exit_wait, first, flex_2d):
-    """Generate iteratively using `generate_enex_nb` and `adv_stop_choice_nb`.
+def generate_ohlc_stop_ex_iter_nb(entries, open, high, low, close, hit_price_out, stop_type_out,
+                                  sl_stop, ts_stop, tp_stop, is_open_safe, entry_wait,
+                                  exit_wait, first, flex_2d):
+    """Generate iteratively using `generate_enex_nb` and `ohlc_stop_choice_nb`.
 
     Returns two arrays: new entries and exits."""
     temp_idx_arr = np.empty((entries.shape[0],), dtype=np.int_)
@@ -649,7 +700,7 @@ def generate_adv_stop_ex_iter_nb(entries, open, high, low, close, hit_price_out,
         entries.shape,
         entry_wait, exit_wait,
         first_choice_nb, (entries,),
-        adv_stop_choice_nb, (
+        ohlc_stop_choice_nb, (
             open, high, low, close, hit_price_out, stop_type_out,
             sl_stop, ts_stop, tp_stop, is_open_safe, exit_wait, first, temp_idx_arr, flex_2d
         )
@@ -912,10 +963,6 @@ def rank_partitions_nb(a, reset_by=None, after_false=False):
 
 # ############# Boolean operations ############# #
 
-# Boolean operations are natively supported by pandas
-# You can, for example, perform Signals_1 & Signals_2 to get logical AND of both arrays
-# NOTE: We don't implement backward operations to avoid look-ahead bias!
-
 @njit(cache=True)
 def fshift_1d_nb(a, n):
     """Shift forward `a` by `n` positions."""
