@@ -2,7 +2,6 @@
 
 import inspect
 import sys
-from types import FunctionType, MethodType
 
 from vectorbt.utils.decorators import custom_property
 
@@ -22,13 +21,3 @@ def list_module_keys(module_name, whitelist=[], blacklist=[]):
             if (not name.startswith("_") and is_from_module(obj, module)
                 and ((inspect.isroutine(obj) and callable(obj)) or inspect.isclass(obj))
                 and name not in blacklist) or name in whitelist]
-
-
-def fix_class_for_docs(cls):
-    """Make functions and properties that were defined in any superclass of `cls` visible 
-    in the documentation of `cls`."""
-    for func_name in dir(cls):
-        if not func_name.startswith("_"):
-            func = getattr(cls, func_name)
-            if isinstance(func, (FunctionType, MethodType, property, custom_property)):
-                setattr(cls, func_name, func)
